@@ -18,13 +18,13 @@ import logging
 import monascastatsd
 import time
 
-from monasca_common.kafka.consumer import KafkaConsumer
-from monasca_common.kafka.producer import KafkaProducer
+from monasca_common.kafka import consumer
+from monasca_common.kafka import producer
 from monasca_notification.common.repositories import exceptions
 from monasca_notification.common.utils import construct_notification_object
 from monasca_notification.common.utils import get_db_repo
-from processors.base import BaseProcessor
-from processors.notification_processor import NotificationProcessor
+from processors import base
+from processors import notification_processor
 
 log = logging.getLogger(__name__)
 
@@ -33,19 +33,20 @@ class PeriodicEngine(object):
     def __init__(self, config, period):
         self._topic_name = config['kafka']['periodic'][period]
 
-        self._statsd = monascastatsd.Client(name='monasca',
-                                            dimensions=BaseProcessor.dimensions)
+        self._statsd = monascastatsd.Client(
+            name='monasca',
+            dimensions=base.BaseProcessor.dimensions)
 
         zookeeper_path = config['zookeeper']['periodic_path'][period]
-        self._consumer = KafkaConsumer(config['kafka']['url'],
-                                       config['zookeeper']['url'],
-                                       zookeeper_path,
-                                       config['kafka']['group'],
-                                       self._topic_name)
+        self._consumer = consumer.KafkaConsumer(config['kafka']['url'],
+                                                config['zookeeper']['url'],
+                                                zookeeper_path,
+                                                config['kafka']['group'],
+                                                self._topic_name)
 
-        self._producer = KafkaProducer(config['kafka']['url'])
+        self._producer = producer.KafkaProducer(config['kafka']['url'])
 
-        self._notifier = NotificationProcessor(config)
+        self._notifier = notification_processor.NotificationProcessor(config)
         self._db_repo = get_db_repo(config)
         self._period = period
 
